"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.watchSchema = exports.makeSchema = void 0;
require("@dataplan/pg/adaptors/pg");
const graphile_build_1 = require("graphile-build");
const graphile_config_1 = require("graphile-config");
/**
 * Builds the GraphQL schema by resolving the preset, running inflection then
 * gather and building the schema. Returns the results.
 *
 * @experimental
 */
async function makeSchema(preset) {
    const resolvedPreset = (0, graphile_config_1.resolvePresets)([preset]);
    const shared = { inflection: (0, graphile_build_1.buildInflection)(resolvedPreset) };
    const input = await (0, graphile_build_1.gather)(resolvedPreset, shared);
    const schema = (0, graphile_build_1.buildSchema)(resolvedPreset, input, shared);
    return { schema, resolvedPreset };
}
exports.makeSchema = makeSchema;
/**
 * Runs the "gather" phase in watch mode and calls 'callback' with the
 * generated ServerParams each time a new schema is generated.
 *
 * It is guaranteed that `callback` will be called at least once before the
 * promise resolves.
 *
 * Returns a function that can be called to stop watching.
 *
 * @experimental
 */
async function watchSchema(preset, callback) {
    const resolvedPreset = (0, graphile_config_1.resolvePresets)([preset]);
    const shared = { inflection: (0, graphile_build_1.buildInflection)(resolvedPreset) };
    const stopWatching = await (0, graphile_build_1.watchGather)(resolvedPreset, shared, (input, error) => {
        if (error) {
            callback(error);
        }
        else {
            const schema = (0, graphile_build_1.buildSchema)(resolvedPreset, input, shared);
            callback(null, { schema, resolvedPreset });
        }
    });
    return stopWatching;
}
exports.watchSchema = watchSchema;
/*
import { exportSchema } from "graphile-export";

  const exportFileLocation = `${__dirname}/../../temp.mjs`;
  await exportSchema(schema, exportFileLocation, {
    mode: "typeDefs",
    modules: {
      jsonwebtoken: jsonwebtoken,
    },
  });
  const { schema: schema2 } = await import(exportFileLocation.toString());
  */
//# sourceMappingURL=schema.js.map